# jekyll-spree-client

Create shopping carts with Jekyll and Spree :)

This plugin provides integration between a Jekyll site and the Spree
API.  It allows to manage products from Jekyll posts and it will create
them on the Spree Store when they don't exist and keep prices and stock
synchronized.

## A note on money and currency formatting

Earlier versions of `spree-api-client` would be sending prices as
strings, making Spree try to convert them from a localized version.
Since it changed to sending data as JSON, Spree doesn't have to do this
conversion unless you store prices as strings.

You can use Integer and Floats now!

### Update

The issue is that Spree expects to receive prices in the locale format
(ie, "200,00") but will return them on Ruby's `to_s` conversion
("200.0") so we need to reconvert them to our current format and juggle
between them.

We'll deal with `Integer` for now until we find [a better
solution](https://github.com/spree/spree/issues/10556).

## Installation

Add this line to your site's Gemfile:

```ruby
gem 'jekyll-spree-client'
```

And then execute:

    $ bundle

Or install it yourself as:

    $ gem install jekyll-spree-client

## Usage

Add the plugin to your `_config.yml`:

```yaml
plugins:
- jekyll-spree-client
spree:
  sku_field: sku
  api_url: http://localhost:3000
  shipping_category_id: 1
```

You can get the API key on your user profile.  Pass it as the
`SPREE_API_KEY` environment variable so you don't store it on your site.

```bash
SPREE_API_KEY="some random value generated by spree" bundle exec jekyll build
```

Since v0.1.4 you can pass the store URL too, and it'll take precedence
over `_config.yml`:

```bash
SPREE_URL="https://your-store.tienda.sutty.nl"
```

### Posts

Add the required fields in their frontmatter:

```yaml
---
layout: post
title: A product
sku: A unique ID
price: 100.00
stock: 100
weight: 100
height: 100
width: 100
depth: 100
---
```

The layout doesn't matter, but we recommend to use a layout for
products.

### Building the site

During site build, the plugin will communicate with the Spree API and
create products when they don't exist or update their price, current
stock and the other values.

Some fields will appear on the frontmatter:

```yaml
variant_id: 1
in_stock: true
sync_error: 2020-10-10 00:00:00 UTC
```

* `variant_id` is the ID in the Spree database.

* `in_stock` is true or false according to availability (Spree decides
  this).

* `sync_error` if the synchronization fails there will be a timestamp
  here.

## Notes

* All products are created as "master variants" on Spree.  There will be
  no pictures, taxonomies or other values, only basic product
  information.

* The `stock` field is the initial stock, afterwards it will only be
  updated from the Spree store.  If you want to add more stock, update
  the stock on the location, not on the post.  We want this to change in
  the future.

* Stock is added to the default stock location, meaning the first active
  one.  The API doesn't show or allows to query the actual default.

* The `price` is in the default currency.

* If you install the `jekyll-write-and-commit-changes` plugin it will
  save the data back to disk when you build with `JEKYLL_ENV=production`
  environment variable.

* Check the shipping category ID on Spree, since there's no API for it,
  you need to provide it manually, default is `1`.

## Contributing

Bug reports and pull requests are welcome on 0xacab.org at
<https://0xacab.org/sutty/jekyll/jekyll-spree-client>. This
project is intended to be a safe, welcoming space for collaboration, and
contributors are expected to adhere to the [Sutty code of
conduct](https://sutty.nl/en/code-of-conduct/).

If you like our plugins, [please consider
donating](https://donaciones.sutty.nl/en/)!

## License

The gem is available as free software under the terms of the GPL3
License.

## Code of Conduct

Everyone interacting in the jekyll-spree-client project’s
codebases, issue trackers, chat rooms and mailing lists is expected to
follow the [code of conduct](https://sutty.nl/en/code-of-conduct/).
